import functools

from anaconda_auth.exceptions import TokenNotFoundError
from anaconda_auth.token import TokenInfo

from aext_shared.config import SHARED_CONFIG, Environment


def require_api_key(method):
    @functools.wraps(method)
    async def wrapper(self, *args, **kwargs):
        try:
            if Environment.is_local(SHARED_CONFIG["environment_v2"]):
                # It is a local environment - checking for an token existence
                TokenInfo.load()
            # either token exists or it is not a local environment - calling the endpoint
            return await method(self, *args, **kwargs)
        except TokenNotFoundError:
            self.set_status(403, "Forbidden: API Key is missing")
            return

    return wrapper
