import os
import time


def get_username() -> str:
    """
    Gets username account
    """
    return os.getenv("JUPYTERHUB_USER", os.getenv("USERNAME", os.getenv("USER", "unknown")))


def get_boolean_env_var(var_name, default=False):
    """
    Read an environment variable and convert it to a boolean.

    Args:
        var_name (str): The name of the environment variable.
        default (bool): The default value if the environment variable is not set.

    Returns:
        bool: The boolean value of the environment variable.
    """
    value = os.getenv(var_name, str(default))
    return value.lower() in ("true", "1", "t", "y", "yes")


class Timer:
    def __init__(self):
        self.elapsed = None

    def __enter__(self):
        self.start = time.monotonic()
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.elapsed = time.monotonic() - self.start
