import unittest.mock
from unittest import mock

import pytest
from tests.test_assets.sentry_event import sentry_event_test

from aext_shared.sentry import SENTRY_EVENTS_ALLOW_LIST, sentry_before_send


@pytest.mark.parametrize(
    "sentry_event, expected_response",
    [
        ({}, None),
        (None, None),
        (
            {"request": {"url": "http://anaconda.com/aext_panel_server"}},
            {"request": {"url": "http://anaconda.com/aext_panel_server"}},
        ),
        (
            {"stacktrace": {"frames": [{"vars": {"self": "aext_shared_server"}}]}},
            {"stacktrace": {"frames": [{"vars": {"self": "aext_shared_server"}}]}},
        ),
        (
            {"stacktrace": {"frames": [{"abs_path": "aext_core_server"}]}},
            {"stacktrace": {"frames": [{"abs_path": "aext_core_server"}]}},
        ),
        (
            {"stacktrace": {"frames": [{"filename": "aext_core_server"}]}},
            {"stacktrace": {"frames": [{"filename": "aext_core_server"}]}},
        ),
        (
            {"stacktrace": {"frames": [{"filename": "aext_should_not_track"}]}},
            None,
        ),
    ],
)
def test_sentry_send_before(sentry_event, expected_response):
    sentry_hint = {}
    assert sentry_before_send(sentry_event, sentry_hint) == expected_response


def test_sentry_send_before_exception():
    mocked = unittest.mock.Mock()
    mocked.get.side_effect = Exception("Forcing exception")
    assert sentry_before_send(mocked, {}) is None


def test_sentry_events_allowed_list():
    expected_to_be_in_the_list = {
        "aext_project_filebrowser_server",
        "aext_panel_server",
        "aext_shared_server",
        "aext_core_server",
        "aext_share_notebook_server",
        "aext_resource_manager_server",
        "aext_profile_manager_server",
        "aext_lms_notebooks_server",
        "aext_events_server",
        "aext_data_catalog_server",
        "aext_assistant_server",
        "aext_environments_server",
    }
    assert expected_to_be_in_the_list == set(SENTRY_EVENTS_ALLOW_LIST)


def test_sentry_send_before_parser():
    assert sentry_before_send(sentry_event_test, {}) is not None
